=== modified file 'src/IconLoader.cpp'
--- src/IconLoader.cpp	2011-02-09 08:33:32 +0000
+++ src/IconLoader.cpp	2011-02-09 12:24:11 +0000
@@ -25,6 +25,9 @@
 IconLoader::IconLoader ()
 : _idle_id (0)
 {
+  // Option to disable loading, if your testing performance of other things
+  _no_load = g_getenv ("UNITY_ICON_LOADER_DISABLE") != NULL;
+
   _tasks = g_queue_new ();
   _theme = gtk_icon_theme_get_default ();
 }
@@ -55,6 +58,9 @@
   g_return_if_fail (icon_name);
   g_return_if_fail (size > 1);
 
+  if (_no_load)
+    return;
+
   key = Hash (icon_name, size);
 
   if (CacheLookup (key, icon_name, size, slot))
@@ -78,6 +84,9 @@
   g_return_if_fail (gicon_string);
   g_return_if_fail (size > 1);
 
+  if (_no_load)
+    return;
+
   key = Hash (gicon_string, size);
 
   if (CacheLookup (key, gicon_string, size, slot))
@@ -101,6 +110,9 @@
   g_return_if_fail (filename);
   g_return_if_fail (size > 1);
 
+  if (_no_load)
+    return;
+
   key = Hash (filename, size);
 
   if (CacheLookup (key, filename, size, slot))
@@ -396,14 +408,14 @@
       break;
   }
 
-  g_debug ("Iteration took: %f msecs", (g_get_monotonic_time () - time)/1000.0);
+  //g_debug ("Iteration took: %f msecs", (g_get_monotonic_time () - time)/1000.0);
   
   is_empty = g_queue_is_empty (_tasks);
   if (is_empty)
   {
     _idle_id = 0;
 
-    g_debug ("Complete load took: %f msecs", (g_get_monotonic_time () - _idle_start_time)/1000.0);
+    //g_debug ("Complete load took: %f msecs", (g_get_monotonic_time () - _idle_start_time)/1000.0);
   }
 
   return !is_empty;

=== modified file 'src/IconLoader.h'
--- src/IconLoader.h	2011-02-09 08:33:32 +0000
+++ src/IconLoader.h	2011-02-09 12:24:11 +0000
@@ -89,6 +89,8 @@
   static void LoadContentsReady (GObject *object, GAsyncResult *res, IconLoaderTask *task);
  
 private:
+  bool _no_load;
+
   std::map<std::string, GdkPixbuf *> _cache;
   GQueue       *_tasks;
   guint         _idle_id;

=== modified file 'src/PlacesGroup.cpp'
--- src/PlacesGroup.cpp	2011-02-02 23:21:05 +0000
+++ src/PlacesGroup.cpp	2011-02-09 12:24:11 +0000
@@ -51,7 +51,6 @@
   //~ OnMouseLeave.connect (sigc::mem_fun (this, &PlacesGroup::RecvMouseLeave));
 
   _label = new nux::StaticCairoText ("", NUX_TRACKER_LOCATION);
-  _label->SinkReference ();
   _label->SetFont ("Ubuntu normal 11");
   _label->SetTextEllipsize (nux::StaticCairoText::NUX_ELLIPSIZE_END);
   _label->SetTextAlignment (nux::StaticCairoText::NUX_ALIGN_LEFT);
@@ -59,7 +58,6 @@
   _label->SetMinimumWidth (1);
 
   _title = new nux::StaticCairoText ("", NUX_TRACKER_LOCATION);
-  _title->SinkReference ();
   _title->SetFont ("Ubuntu normal 11");
   _title->SetTextEllipsize (nux::StaticCairoText::NUX_ELLIPSIZE_END);
   _title->SetTextAlignment (nux::StaticCairoText::NUX_ALIGN_RIGHT);
@@ -67,7 +65,6 @@
   _title->SetMinimumWidth (1);
 
   _header_layout = new nux::HLayout ("", NUX_TRACKER_LOCATION);
-  _header_layout->SinkReference ();
 
   _header_layout->AddView (_title, 0, nux::MINOR_POSITION_TOP, nux::MINOR_SIZE_FULL);
   _header_layout->AddSpace (1, 1);
@@ -76,7 +73,6 @@
   // _header_layout->AddView (_label, 0, nux::MINOR_POSITION_TOP, nux::MINOR_SIZE_FULL);
 
   _group_layout = new nux::VLayout ("", NUX_TRACKER_LOCATION);
-  _group_layout->SinkReference ();
 
   _group_layout->AddLayout (_header_layout, 0, nux::MINOR_POSITION_TOP, nux::MINOR_SIZE_FULL);
 
@@ -93,9 +89,6 @@
 
 PlacesGroup::~PlacesGroup ()
 {
-  _label->UnReference ();
-  _title->UnReference ();
-
   g_free (_title_string);
 
   _group_layout->RemoveChildObject (_header_layout);
@@ -103,12 +96,7 @@
   if (_content != NULL)
   {
     _group_layout->RemoveChildObject (_content);
-    _content->UnReference ();
   }
-
-  _header_layout->UnReference ();
-  _group_layout->UnReference ();
-
 }
 
 void PlacesGroup::SetTitle (const char *title)
@@ -124,13 +112,10 @@
 void PlacesGroup::AddLayout (nux::Layout *layout)
 {
   _content = layout;
-  _content->Reference ();
 
   // By setting the stretch factor of the GridHLayout to 0, the height of the grid
   // will be forced to the height that is necessary to include all its elements.
   _group_layout->AddLayout (_content, 0);
-
-  ComputeChildLayout ();
   NeedRedraw ();
 }
 
@@ -219,16 +204,6 @@
 void PlacesGroup::Draw (nux::GraphicsEngine& GfxContext,
                        bool                 forceDraw)
 {
-  // Check if the texture have been computed. If they haven't, exit the function.
-  nux::Geometry base = GetGeometry ();
-  nux::GetPainter ().PaintBackground (GfxContext, GetGeometry ());
-
-
-  GfxContext.PushClippingRectangle (base);
-
-  _group_layout->NeedRedraw ();
-
-  GfxContext.PopClippingRectangle ();
 }
 
 void

=== modified file 'src/PlacesResultsController.cpp'
--- src/PlacesResultsController.cpp	2011-02-07 11:43:30 +0000
+++ src/PlacesResultsController.cpp	2011-02-09 12:24:11 +0000
@@ -146,8 +146,6 @@
 PlacesGroup *
 PlacesResultsController::CreateGroup (const char *groupname)
 {
-  g_debug ("CreateGroup: %s", groupname);
-
   PlacesGroup *newgroup = new PlacesGroup (NUX_TRACKER_LOCATION);
   newgroup->SinkReference ();
   newgroup->SetTitle (groupname);

=== modified file 'src/PlacesResultsView.cpp'
--- src/PlacesResultsView.cpp	2011-01-31 12:48:36 +0000
+++ src/PlacesResultsView.cpp	2011-02-09 12:24:11 +0000
@@ -32,7 +32,6 @@
   m_horizontal_scrollbar_enable   = false;
   m_vertical_scrollbar_enable      = true;
   _layout = new nux::VLayout ("", NUX_TRACKER_LOCATION);
-  _layout->SinkReference ();
 
   _layout->SetContentDistribution(nux::MAJOR_POSITION_TOP);
 
@@ -44,14 +43,7 @@
 
 PlacesResultsView::~PlacesResultsView ()
 {
-  std::list<PlacesGroup *>::iterator it;
-  for (it = _groups.begin(); it != _groups.end(); it++)
-  {
-    (*it)->UnReference ();
-  }
-
   _layout->Clear ();
-  _layout->UnReference ();
 }
 
 void
@@ -72,21 +64,6 @@
 void
 PlacesResultsView::Draw (nux::GraphicsEngine &GfxContext, bool force_draw)
 {
-  GfxContext.PushClippingRectangle (GetGeometry() );
-
-  nux::Geometry base = GetGeometry();
-
-  if (_layout)
-    _layout->NeedRedraw();
-
-  nux::GetPainter().PaintBackground (GfxContext, base);
-
-  if (m_vertical_scrollbar_enable)
-  {
-    vscrollbar->NeedRedraw();
-  }
-
-  GfxContext.PopClippingRectangle();
 }
 
 void
@@ -94,21 +71,11 @@
 {
   GfxContext.PushClippingRectangle (GetGeometry() );
 
-  GfxContext.PushClippingRectangle (nux::Rect (m_ViewX, m_ViewY, m_ViewWidth, m_ViewHeight) );
-
   if (_layout)
-  {
-    GfxContext.PushClippingRectangle (_layout->GetGeometry() );
     _layout->ProcessDraw (GfxContext, force_draw);
-    GfxContext.PopClippingRectangle();
-  }
-
-  GfxContext.PopClippingRectangle();
 
   if (m_vertical_scrollbar_enable)
-  {
     vscrollbar->ProcessDraw (GfxContext, force_draw);
-  }
 
   GfxContext.PopClippingRectangle();
 }
@@ -116,19 +83,15 @@
 void
 PlacesResultsView::AddGroup (PlacesGroup *group)
 {
-  group->Reference ();
   _groups.push_back (group);
   _layout->AddView (group, 0, nux::MINOR_POSITION_CENTER, nux::MINOR_SIZE_FULL);
-  ComputeChildLayout ();
 }
 
 void
 PlacesResultsView::RemoveGroup (PlacesGroup *group)
 {
-  group->UnReference ();
   _groups.remove (group);
   _layout->RemoveChildObject (group);
-  ComputeChildLayout ();
 }
 
 void
@@ -207,14 +170,10 @@
 PlacesResultsView::ScrollUp (float stepy, int mousedy)
 {
   ScrollView::ScrollUp (stepy, mousedy);
-  ComputeChildLayout();
-  NeedRedraw();
 }
 
 void
 PlacesResultsView::ScrollDown (float stepy, int mousedy)
 {
   ScrollView::ScrollDown (stepy, mousedy);
-  ComputeChildLayout();
-  NeedRedraw();
 }

=== modified file 'src/PlacesView.cpp'
--- src/PlacesView.cpp	2011-02-09 08:35:17 +0000
+++ src/PlacesView.cpp	2011-02-09 12:24:11 +0000
@@ -58,6 +58,8 @@
   _results_controller->SetView (_results_view);
   _layered_layout->AddLayer (_results_view);
 
+  _layered_layout->SetActiveLayer (_home_view);
+
   SetCompositionLayout (_layout);
 
   // Register for all the events
@@ -109,6 +111,7 @@
   if (_entry)
   {
     _entry->SetActive (false);
+
     g_signal_handler_disconnect (_entry->GetGroupsModel (), _group_added_id);
     g_signal_handler_disconnect (_entry->GetGroupsModel (), _group_removed_id);
     g_signal_handler_disconnect (_entry->GetResultsModel (), _result_added_id);
@@ -118,13 +121,13 @@
 
     _results_controller->Clear ();
   }
-
+  
   _entry = entry;
   
   if (_entry)
   {
     std::map <gchar*, gchar*> hints;
-    DeeModel     *groups;
+    DeeModel     *groups, *results;
     DeeModelIter *iter, *last;
 
     _entry->SetActive (true);
@@ -140,6 +143,15 @@
       iter = dee_model_next (groups, iter);
     }
 
+    results = _entry->GetResultsModel ();
+    iter = dee_model_get_first_iter (results);
+    last = dee_model_get_last_iter (results);
+    while (iter != last)
+    {
+      OnResultAdded (results, iter, this);
+      iter = dee_model_next (results, iter);
+    }
+
     _group_added_id = g_signal_connect (_entry->GetGroupsModel (), "row-added",
                                         (GCallback)&PlacesView::OnGroupAdded, this);
     _group_removed_id = g_signal_connect (_entry->GetGroupsModel (), "row-removed",
@@ -148,7 +160,14 @@
                                          (GCallback)&PlacesView::OnResultAdded, this);
     _result_removed_id = g_signal_connect (_entry->GetResultsModel (), "row-removed",
                                            (GCallback)&PlacesView::OnResultRemoved, this);
-  }
+
+    _layered_layout->SetActiveLayer (_results_view);
+  }
+  else
+  {
+    _layered_layout->SetActiveLayer (_home_view);
+  }
+
   _search_bar->SetActiveEntry (_entry, section_id, search_string);
 
   if (signal)

